"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRegexValidatorFn = void 0;
/**
 * Returns a function which takes an unknown input, and returns `true` if the input
 * is a string which conforms to the provided `regex` pattern(s).
 *
 * Implementation note: the `RegExp.prototype.test()` method does not throw an error
 * if the input is not a string, so it's unnecessary to check the input type, hence
 * the `as string` type casts.
 *
 * @internal
 */
const getRegexValidatorFn = (regexArg) => {
    return Array.isArray(regexArg)
        ? (value) => regexArg.every((regex) => regex.test(value))
        : (value) => regexArg.test(value);
};
exports.getRegexValidatorFn = getRegexValidatorFn;
